@@ -7,32 +7,7 @@ use HTML::TableExtract;
 use LWP::UserAgent;
 use DateTime;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Bank::Holidays ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = (
-  'all' => [
-    qw( is_holiday reserve_holidays
-
-      )
-  ]
-);
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-
-);
-
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 
 sub new {
   my ( $package, %params ) = @_;
@@ -51,7 +26,7 @@ sub new {
 sub reserve_holidays() {
   my $te = HTML::TableExtract->new();
 
-  my $ua = new LWP::UserAgent;
+  my $ua = LWP::UserAgent->new();
 
   $ua->timeout(120);
 
@@ -77,7 +52,7 @@ sub reserve_holidays() {
   else {
     my $url = 'http://www.federalreserve.gov/aboutthefed/k8.htm';
 
-    my $request = new HTTP::Request( 'GET', $url );
+    my $request = HTTP::Request->new( 'GET', $url );
 
     my $response = $ua->request($request);
 
@@ -168,7 +143,7 @@ Bank::Holidays - Perl extension for determining Federal Reserve holidays. 2015 -
 
 =head1 VERSION
 
-0.81
+0.82
 
 =head1 SYNOPSIS
 
@@ -192,11 +167,16 @@ Bank::Holidays - Perl extension for determining Federal Reserve holidays. 2015 -
   $bank->is_holiday( Tomorrow => 1 ) ? print "is" : print "is not";
   print " a holiday\n";
 
+=head1 EXPORTER
+
+As of version 0.82, no functions are exported, and EXPORTER has been removed. It's
+unclear if exported functions worked, as both (`is_holiday' and `reserve_holidays')
+required an existing Bank::Holidays object to have been created by the caller.
 
 =head1 DESCRIPTION
 
 Bank::Holidays reads a page from the Federal Reserve's website that contains
-holidays until 2016. However should the FR's site change this code may not work.
+holidays until 2019. However should the FR's site change this code may not work.
 This code is very useful for determining days that a valid banking transaction
 can occur, remembering that Sunday is never a banking day.
 
